==> flyspray_0.9.6a.orig.tar.gz: flyspray-0.9.6/lang/pl/details.php <==
<?php

// Tłumaczenie na języki polski
// Translation to Polish
//
// Tomek 'TomasH' Zielinski
// tomash@fidonet.org.pl, tomash@4net.pl
// 
// Uzupełnienia od wersji 0.9.5:
// Konrad Roziewski <konrad#suwalki-com-pl>

$details_text = array (

'task'		=>	'Zgłoszenie',
'edittask'	=>	'Edytuj zgłoszenie',
'openedby'	=>	'Otworzył',
'editedby'	=>	'Ostatnio edytował',
'tasktype'	=>	'Typ zgłoszenia',
'category'	=>	'Kategoria',
'status'	=>	'Status',
'assignedto'	=>	'Przydzielony dla',
'noone'		=>	'Nikogo',
'operatingsystem'	=>	'System operacyjny',
'severity'	=>	'Dotkliwość',
'reportedversion'	=>	'Dotyczy wersji',
'dueinversion'	=>	'Obecne do wersji',
'undecided'	=>	'Nie wskazano',
'percentcomplete'	=>	'Procent postępu',
'details'	=>	'Szczegóły',
'savedetails'	=>	'Zapisz szczegóły',
'canceledit'	=>	'Anuluj',
'anonymous'	=>	'Anonimowy zgłaszający',
'complete'	=>	'gotowe',
'closedby'	=>	'Zamknięte przez',
'reasonforclosing'	=>	'Powód zamknięcia:',
'reopenthistask'	=>	'Ponownie otwórz zgłoszenie',
'closetask'	=>	'Zamknij zgłoszenie',
'comments'	=>	'Komentarze',
'attachments'	=>	'Załączniki',
'relatedtasks'	=>	'Powiązane zgłoszenia',
'notifications'	=>	'Powiadomienia',
'edit'		=>	'Edycja',
'delete'	=>	'Kasuj',
'commentby'	=>	'Komentarz od',
'addcomment'	=>	'Dodaj komentarz',
'fileuploadedby'=>	'Plik przysłany przez',
'uploadafile'	=>	'Wyślij załącznik',
'description'	=>	'Opis',
'uploadnow'	=>	'Wyślij teraz!',
'thesearerelated'	=>	'Te zgłoszenia są powiązane z oglądanym',
'remove'	=>	'Usuń',
'addnewrelated'	=>	'Dodaj nowe powiązanie',
'add'		=>	'Dodaj!',
'otherrelated'	=>	'Inne zgłoszenia, z którymi powiązane jest obecne',
'receivenotify'	=>	'Ci użytkownicy zostaną powiadomieni o zmianach w tym zgłoszeniu.',
'addusertolist'	=>	'Dodaj użytkownika do listy',
'addtolist'	=>	'Dodaj do listy',
'addmyself'	=>	'Dodaj mnie do listy',
'removemyself'	=>	'Usuń mnie z listy',
'invalidtaskid'	=>	'Nie ma zgłoszenia z takim ID!',
'theseusersnotify'	=>	'Ci użytkownicy będą powiadamieni o zmianach w tym zgłoszeniu.',

// Added in version 0.9.5

'attachedtoproject'	=>	'Przydzielony do projektu',

// Added in version 0.9.6

'reminders'         =>   'Przypomnienia',
'system'            =>   'System',
'remindthisuser'    =>   'Przypomnij użytkownikowi',
'thisoften'         =>   'Z częstotliwością',
'startafter'        =>   'Odczekaj z przypominaniem',
'hours'             =>   'Godzin',
'days'              =>   'Dni',
'weeks'             =>   'Tygodni',
'addreminder'       =>   'Dodaj przypomnienie',
'defaultreminder'   =>   "To jest przypomnienie, by zająć się zadaniem Flyspray'a: ",
'message'           =>   'Wiadomość',
'closed'			=>   'Zamknięte',
'filename'			=>   'Nazwa pliku:',
'date'				=>   'Data:',
'filesize'			=>   'Rozmiar pliku:',
'closurecomment'	=>   'Dodatkowe uwagi dotyczące zamknięcia:',

'history'           =>   'Historia',
'nohistory'         =>   'To zgłoszenie nie ma historii.',
'eventdate'         =>   'Data',
'user'              =>   'Użytkownik',
'event'             =>   'Zdarzenie',
'fieldchanged'      =>   'Zmiana pola',
'taskopened'        =>   'Otwarcie zgłoszenia',
'taskreopened'      =>   'Powtórne otwarcie zgłoszenia',
'taskclosed'        =>   'Zamknięcie zgłoszenia',
'commentadded'      =>   'Nowy komentarz',
'commentedited'     =>   'Zmiana komentarza',
'commentdeleted'    =>   'Usunięcie komentarza',
'attachmentadded'   =>   'Dodanie załącznika',
'attachmentdeleted' =>   'Usunięcie załącznika',
'taskedited'        =>   'Zmiana szczegółów zgłoszenia',
'notificationadded' =>   'Dodanie użytkownika do listy powiadomień',
'notificationdeleted' => 'Usunięcie użytkownika z listy powiadomień',
'relatedadded'      =>   'Dodanie powiązanego zgłoszenia',
'relateddeleted'    =>   'Usunięcie powiązanego zgłoszenia',
'taskassigned'      =>   'Zgłoszenie przydzielone dla',
'taskreassigned'    =>   'Zmiana przydziału zgłoszenia dla',
'assignmentremoved' =>   'Usunięcie przydziału zgłoszenia',
'summary'           =>   'Podsumowanie',
'addedasrelated'    =>   'Zgłoszenie powiązane ze zgłoszeniem',
'deletedasrelated'  =>   'Usunięcie powiązania ze zgłoszeniem',
'reminderadded'     =>   'Przypomnienie dodane',
'reminderdeleted'   =>   'Przypomnienie usunięte',
'priority'          =>   'Priorytet',
'previousvalue'     =>   'Poprzednia wartość',
'newvalue'          =>   'Nowa wartość',

);
// vim:fenc=utf-8:enc=utf-8
?>

==> flyspray_0.9.7.orig.tar.gz: flyspray-0.9.7/lang/pl/details.php <==
<?php

// Tłumaczenie na języki polski
// Translation to Polish
//
// Tomek 'TomasH' Zielinski
// tomash@fidonet.org.pl, tomash@4net.pl
// 
// Uzupełnienia od wersji 0.9.5:
// Konrad Roziewski <konrad#suwalki-com-pl>

$details_text = array (

'task'		=>	'Zgłoszenie',
'edittask'	=>	'Edytuj zgłoszenie',
'openedby'	=>	'Otworzył',
'editedby'	=>	'Ostatnio edytował',
'tasktype'	=>	'Typ zgłoszenia',
'category'	=>	'Kategoria',
'status'	=>	'Status',
'assignedto'	=>	'Przydzielony dla',
'noone'		=>	'Nikogo',
'operatingsystem'	=>	'System operacyjny',
'severity'	=>	'Ważność',
'reportedversion'	=>	'Dotyczy wersji',
'dueinversion'	=>	'Obecne do wersji',
'undecided'	=>	'Nie wskazano',
'percentcomplete'	=>	'Procent postępu',
'details'	=>	'Szczegóły',
'savedetails'	=>	'Zapisz szczegóły',
'canceledit'	=>	'Anuluj',
'anonymous'	=>	'Anonimowy zgłaszający',
'complete'	=>	'gotowe',
'closedby'	=>	'Zamknięte przez',
'reasonforclosing'	=>	'Powód zamknięcia:',
'reopenthistask'	=>	'Ponownie otwórz zgłoszenie',
'closetask'	=>	'Zamknij zgłoszenie',
'comments'	=>	'Komentarze',
'attachments'	=>	'Załączniki',
'relatedtasks'	=>	'Powiązane zgłoszenia',
'notifications'	=>	'Powiadomienia',
'edit'		=>	'Edycja',
'delete'	=>	'Kasuj',
'commentby'	=>	'Komentarz od',
'addcomment'	=>	'Dodaj komentarz',
'fileuploadedby'=>	'Plik przysłany przez',
'uploadafile'	=>	'Wyślij załącznik',
'description'	=>	'Opis',
'uploadnow'	=>	'Wyślij teraz!',
'thesearerelated'	=>	'Te zgłoszenia są powiązane z oglądanym',
'remove'	=>	'Usuń',
'addnewrelated'	=>	'Dodaj nowe powiązanie',
'add'		=>	'Dodaj!',
'otherrelated'	=>	'Inne zgłoszenia, z którymi powiązane jest obecne',
'receivenotify'	=>	'Ci użytkownicy zostaną powiadomieni o zmianach w tym zgłoszeniu.',
'addusertolist'	=>	'Dodaj użytkownika do listy',
'addtolist'	=>	'Dodaj do listy',
'addmyself'	=>	'Dodaj mnie do listy',
'removemyself'	=>	'Usuń mnie z listy',
'invalidtaskid'	=>	'Nie ma zgłoszenia z takim ID!',
'theseusersnotify'	=>	'Ci użytkownicy będą powiadamieni o zmianach w tym zgłoszeniu.',

// Added in version 0.9.5

'attachedtoproject'	=>	'Przydzielony do projektu',

// Added in version 0.9.6

'reminders'         =>   'Przypomnienia',
'system'            =>   'System',
'remindthisuser'    =>   'Przypomnij użytkownikowi',
'thisoften'         =>   'Z częstotliwością',
'startafter'        =>   'Odczekaj z przypominaniem',
'hours'             =>   'Godzin',
'days'              =>   'Dni',
'weeks'             =>   'Tygodni',
'addreminder'       =>   'Dodaj przypomnienie',
'defaultreminder'   =>   "To jest przypomnienie, by zająć się zadaniem Flyspray'a: ",
'message'           =>   'Wiadomość',
'closed'	    =>   'Zamknięte',
'filename'	    =>   'Nazwa pliku:',
'date'		    =>   'Data:',
'filesize'	    =>   'Rozmiar pliku:',
'closurecomment'    =>   'Dodatkowe uwagi dotyczące zamknięcia:',

'history'           =>   'Historia',
'nohistory'         =>   'To zgłoszenie nie ma historii.',
'eventdate'         =>   'Data',
'user'              =>   'Użytkownik',
'event'             =>   'Zdarzenie',
'fieldchanged'      =>   'Zmiana pola',
'taskopened'        =>   'Otwarcie zgłoszenia',
'taskreopened'      =>   'Powtórne otwarcie zgłoszenia',
'taskclosed'        =>   'Zamknięcie zgłoszenia',
'commentadded'      =>   'Nowy komentarz',
'commentedited'     =>   'Zmiana komentarza',
'commentdeleted'    =>   'Usunięcie komentarza',
'attachmentadded'   =>   'Dodanie załącznika',
'attachmentdeleted' =>   'Usunięcie załącznika',
'taskedited'        =>   'Zmiana szczegółów zgłoszenia',
'notificationadded' =>   'Dodanie użytkownika do listy powiadomień',
'notificationdeleted' => 'Usunięcie użytkownika z listy powiadomień',
'relatedadded'      =>   'Dodanie powiązanego zgłoszenia',
'relateddeleted'    =>   'Usunięcie powiązanego zgłoszenia',
'taskassigned'      =>   'Zgłoszenie przydzielone dla',
'taskreassigned'    =>   'Zmiana przydziału zgłoszenia dla',
'assignmentremoved' =>   'Usunięcie przydziału zgłoszenia',
'summary'           =>   'Podsumowanie',
'addedasrelated'    =>   'Zgłoszenie powiązane ze zgłoszeniem',
'deletedasrelated'  =>   'Usunięcie powiązania ze zgłoszeniem',
'reminderadded'     =>   'Dodanie przypomnienia',
'reminderdeleted'   =>   'Usunięcie przypomnienia',
'priority'          =>   'Priorytet',
'previousvalue'     =>   'Poprzednia wartość',
'newvalue'          =>   'Nowa wartość',

// Added in version 0.9.7

'selectareason'       =>   'Wybierz powód',
'assigntome'          =>   'Przydziel mi',
'reopenrequest'       =>   'Poproś o ponowne otwarcie',
'requestclose'        =>   'Poproś o zamknięcie',
'ownershiptaken'      =>   'Użytkownik przejął zgłoszenie',
'closerequestmade'    =>   'Prośba o zamknięcie zgłoszenia',
'reopenrequestmade'   =>   'Prośba o ponowne otwarcie zgłoszenia',
'taskdependson'       =>   'Zgłoszenie zależy od',
'taskblocks'          =>   'Zgłoszenie blokuje następujące zgłoszenia',
'addnew'              =>   'Dodaj nowe',
'depadded'            =>   'Dodana zależność:',
'depaddedother'       =>   'Dodane zgłoszenie zależne:',
'depremoved'          =>   'Usunięta zależność:',
'depremovedother'     =>   'Zgłoszenie usunięte z listy zależności innego zgłoszenia:',
'showdetailserror'    =>   'Zgłoszenie nie istnieje lub nie masz uprawnień, by je oglądać.',
'makeprivate'         =>   'Zmień na prywatne',	// FIXME: prywatne/publiczne
'makepublic'          =>   'Zmień na publiczne',
'taskmadeprivate'    =>    'Zgłoszenie zmienione na prywatne',
'taskmadepublic'     =>    'Prywatność usunięta - zgłoszenie zmienione na publiczne',

);
// vim:fenc=utf-8:enc=utf-8
?>
